use chrono::NaiveDate;
use serde::Serialize;
use sqlx::SqlitePool;

use self::{
    planned_event::{PlannedEvent, PlannedEventWithUserAndTriptype},
    trip::{Trip, TripWithUserAndType},
};

pub mod log;
pub mod planned_event;
pub mod trip;
pub mod tripdetails;
pub mod triptype;
pub mod user;
pub mod usertrip;

#[derive(Serialize)]
pub struct Day {
    day: NaiveDate,
    planned_events: Vec<PlannedEventWithUserAndTriptype>,
    trips: Vec<TripWithUserAndType>,
}

impl Day {
    pub async fn new(db: &SqlitePool, day: NaiveDate) -> Self {
        Self {
            day,
            planned_events: PlannedEvent::get_for_day(db, day).await,
            trips: Trip::get_for_day(db, day).await,
        }
    }
    pub async fn new_guest(db: &SqlitePool, day: NaiveDate) -> Self {
        let mut day = Self::new(db, day).await;

        day.planned_events = day
            .planned_events
            .into_iter()
            .filter(|e| e.planned_event.allow_guests)
            .collect();

        day.trips = day
            .trips
            .into_iter()
            .filter(|t| t.trip.allow_guests)
            .collect();

        day
    }
}
